package POE::Filter::IASLog;

use strict;
use Parse::IASLog;
use base qw(POE::Filter);
use vars qw($VERSION);

$VERSION = '0.01';

sub new {
  my $class = shift;
  my %opts = @_;
  $opts{lc $_} = delete $opts{$_} for keys %opts;
  $opts{BUFFER} = [];
  $opts{IAS} = Parse::IASLog->new();
  return bless \%opts, $class;
}

sub get_one_start {
  my ($self, $raw) = @_;
  push @{ $self->{BUFFER} }, $_ for @$raw;
}

sub get_one {
  my $self = shift;
  my $events = [];

  my $event = shift @{ $self->{BUFFER} };
  if ( defined $event ) {
    my $record = $self->{IAS}->parse($event);
    push @$events, $record if $record;
  }
  return $events;
}

sub get_pending {
  my $self = shift;
  return $self->{BUFFER};
}

sub put {
  return;
}

1;
__END__

=head1 NAME

POE::Filter::IASLog - A POE Filter for Microsoft IAS-formatted log entries.

=head1 SYNOPSIS

  my $filter = POE::Filter::IASLog->new();

  $arrayref_of_logical_chunks =
    $filter->get($arrayref_of_raw_chunks_from_driver);

=head1 DESCRIPTION

POE::Filter::IASLog is a L<POE::Filter> for parsing lines of text that are formatted in Microsoft
Internet Authentication Service (IAS) log format, where attributes are logged as attribute-value pairs.

It is intended to be used in a stackable filter, L<POE::Filter::Stackable>, with L<POE::Filter::Line>.

=head1 CONSTRUCTOR

=over

=item new

Creates a new POE::Filter::IASLog object.

=back

=head1 METHODS

=over

=item get

=item get_one_start

=item get_one

Takes an arrayref which is contains lines of IAS-formatted text, returns an arrayref of IAS hashref records,
see L<Parse::IASLog> for details of what a record will contain.

=item get_pending

Returns the filter's partial input buffer.

=item put

The put method is not implemented.

=back

=head1 AUTHOR

Chris C<BinGOs> Williams <chris@bingosnet.co.uk>

=head1 SEE ALSO

L<Parse::IASLog>

L<POE::Filter::Stackable>

L<POE::Filter::Line>
